@@ -1,7 +1,8 @@
 {-# LANGUAGE CPP #-}
-module Network.Wai.Middleware.CleanPath
-    ( cleanPath
-    ) where
+
+module Network.Wai.Middleware.CleanPath (
+    cleanPath,
+) where
 
 import qualified Data.ByteString.Char8 as B
 import qualified Data.ByteString.Lazy as L
@@ -12,10 +13,11 @@ import Data.Text (Text)
 import Network.HTTP.Types (hLocation, status301)
 import Network.Wai (Application, pathInfo, rawQueryString, responseLBS)
 
-cleanPath :: ([Text] -> Either B.ByteString [Text])
-          -> B.ByteString
-          -> ([Text] -> Application)
-          -> Application
+cleanPath
+    :: ([Text] -> Either B.ByteString [Text])
+    -> B.ByteString
+    -> ([Text] -> Application)
+    -> Application
 cleanPath splitter prefix app env sendResponse =
     case splitter $ pathInfo env of
         Right pieces -> app pieces env sendResponse
@@ -25,10 +27,10 @@ cleanPath splitter prefix app env sendResponse =
                     status301
                     [(hLocation, mconcat [prefix, p, suffix])]
                     L.empty
-    where
-        -- include the query string if present
-        suffix =
-            case B.uncons $ rawQueryString env of
-                Nothing -> B.empty
-                Just ('?', _) -> rawQueryString env
-                _ -> B.cons '?' $ rawQueryString env
+  where
+    -- include the query string if present
+    suffix =
+        case B.uncons $ rawQueryString env of
+            Nothing -> B.empty
+            Just ('?', _) -> rawQueryString env
+            _ -> B.cons '?' $ rawQueryString env
