@@ -1,4 +1,7 @@
 ---------------------------------------------------------
+
+---------------------------------------------------------
+
 -- |
 -- Module        : Network.Wai.Middleware.HealthCheckEndpoint
 -- Copyright     : Michael Snoyman
@@ -9,12 +12,10 @@
 -- Portability   : portable
 --
 -- Add empty endpoint (for Health check tests)
---
----------------------------------------------------------
-module Network.Wai.Middleware.HealthCheckEndpoint
-  ( healthCheck,
+module Network.Wai.Middleware.HealthCheckEndpoint (
+    healthCheck,
     voidEndpoint,
-  )
+)
 where
 
 import Data.ByteString (ByteString)
@@ -32,6 +33,6 @@ healthCheck = voidEndpoint "/_healthz"
 -- @since 3.1.9
 voidEndpoint :: ByteString -> Middleware
 voidEndpoint endpointPath router request respond =
-  if rawPathInfo request == endpointPath
-    then respond $ responseLBS status200 mempty "-"
-    else router request respond
+    if rawPathInfo request == endpointPath
+        then respond $ responseLBS status200 mempty "-"
+        else router request respond
