@@ -1,5 +1,6 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
+
 module WaiExtraSpec (spec, toRequest) where
 
 import Codec.Compression.GZip (decompress)
@@ -40,7 +41,13 @@ import Test.Hspec
 import Network.Wai.Header (parseQValueList)
 import Network.Wai.Middleware.AcceptOverride (acceptOverride)
 import Network.Wai.Middleware.Autohead (autohead)
-import Network.Wai.Middleware.Gzip (GzipFiles (..), GzipSettings (..), def, defaultCheckMime, gzip)
+import Network.Wai.Middleware.Gzip (
+    GzipFiles (..),
+    GzipSettings (..),
+    def,
+    defaultCheckMime,
+    gzip,
+ )
 import Network.Wai.Middleware.Jsonp (jsonp)
 import Network.Wai.Middleware.MethodOverride (methodOverride)
 import Network.Wai.Middleware.MethodOverridePost (methodOverridePost)
@@ -52,47 +59,50 @@ import Network.Wai.UrlMap (mapUrls, mount, mountRoot)
 
 spec :: Spec
 spec = do
-  describe "Network.Wai.UrlMap" $ do
-    mapM_ (uncurry it) casesUrlMap
+    describe "Network.Wai.UrlMap" $ do
+        mapM_ (uncurry it) casesUrlMap
 
-  describe "Network.Wai" $ do
-    {-
-    , it "findBound" caseFindBound
-    , it "sinkTillBound" caseSinkTillBound
-    , it "killCR" caseKillCR
-    , it "killCRLF" caseKillCRLF
-    , it "takeLine" caseTakeLine
-    -}
-    it "jsonp" caseJsonp
-    describe "gzip" $ do
-        it "gzip" caseGzip
-        it "more gzip" caseGzip2
-        it "gzip not on partial content" caseGzipPartial
-        it "gzip removes length header" caseGzipLength
-        it "gzip not for MSIE" caseGzipMSIE
-        it "gzip bypass when precompressed" caseGzipBypassPre
-        it "defaultCheckMime" caseDefaultCheckMime
-        it "gzip checking of files" caseGzipFiles
-    it "vhost" caseVhost
-    it "autohead" caseAutohead
-    it "method override" caseMethodOverride
-    it "method override post" caseMethodOverridePost
-    it "accept override" caseAcceptOverride
-    it "debug request body" caseDebugRequestBody
-    it "stream file" caseStreamFile
-    it "stream LBS" caseStreamLBS
-    it "can modify POST params before logging" caseModifyPostParamsInLogs
-    it "can filter requests in logs" caseFilterRequestsInLogs
-    it "can parse Q values" caseQValues
+    describe "Network.Wai" $ do
+        {-
+        , it "findBound" caseFindBound
+        , it "sinkTillBound" caseSinkTillBound
+        , it "killCR" caseKillCR
+        , it "killCRLF" caseKillCRLF
+        , it "takeLine" caseTakeLine
+        -}
+        it "jsonp" caseJsonp
+        describe "gzip" $ do
+            it "gzip" caseGzip
+            it "more gzip" caseGzip2
+            it "gzip not on partial content" caseGzipPartial
+            it "gzip removes length header" caseGzipLength
+            it "gzip not for MSIE" caseGzipMSIE
+            it "gzip bypass when precompressed" caseGzipBypassPre
+            it "defaultCheckMime" caseDefaultCheckMime
+            it "gzip checking of files" caseGzipFiles
+        it "vhost" caseVhost
+        it "autohead" caseAutohead
+        it "method override" caseMethodOverride
+        it "method override post" caseMethodOverridePost
+        it "accept override" caseAcceptOverride
+        it "debug request body" caseDebugRequestBody
+        it "stream file" caseStreamFile
+        it "stream LBS" caseStreamLBS
+        it "can modify POST params before logging" caseModifyPostParamsInLogs
+        it "can filter requests in logs" caseFilterRequestsInLogs
+        it "can parse Q values" caseQValues
 
 toRequest :: S8.ByteString -> S8.ByteString -> SRequest
-toRequest ctype content = SRequest defaultRequest
-    { requestHeaders = [("Content-Type", ctype)]
-    , requestMethod = "POST"
-    , rawPathInfo = "/"
-    , rawQueryString = ""
-    , queryString = []
-    } (L.fromChunks [content])
+toRequest ctype content =
+    SRequest
+        defaultRequest
+            { requestHeaders = [("Content-Type", ctype)]
+            , requestMethod = "POST"
+            , rawPathInfo = "/"
+            , rawQueryString = ""
+            , queryString = []
+            }
+        (L.fromChunks [content])
 
 {-
 caseFindBound :: Assertion
@@ -146,28 +156,36 @@ caseTakeLine = do
 -}
 
 jsonpApp :: Application
-jsonpApp = jsonp $ \_ f -> f $ responseLBS
-    status200
-    [("Content-Type", "application/json")]
-    "{\"foo\":\"bar\"}"
+jsonpApp = jsonp $ \_ f ->
+    f $
+        responseLBS
+            status200
+            [("Content-Type", "application/json")]
+            "{\"foo\":\"bar\"}"
 
 caseJsonp :: Assertion
 caseJsonp = withSession jsonpApp $ do
-    sres1 <- request defaultRequest
+    sres1 <-
+        request
+            defaultRequest
                 { queryString = [("callback", Just "test")]
                 , requestHeaders = [("Accept", "text/javascript")]
                 }
     assertContentType "text/javascript" sres1
     assertBody "test({\"foo\":\"bar\"})" sres1
 
-    sres2 <- request defaultRequest
+    sres2 <-
+        request
+            defaultRequest
                 { queryString = [("call_back", Just "test")]
                 , requestHeaders = [("Accept", "text/javascript")]
                 }
     assertContentType "application/json" sres2
     assertBody "{\"foo\":\"bar\"}" sres2
 
-    sres3 <- request defaultRequest
+    sres3 <-
+        request
+            defaultRequest
                 { queryString = [("callback", Just "test")]
                 , requestHeaders = [("Accept", "text/html")]
                 }
@@ -179,12 +197,15 @@ gzipApp = gzipApp' id
 
 gzipApp' :: (Response -> Response) -> Application
 gzipApp' changeRes =
-    gzip def $ \_ f -> f . changeRes $ responseLBS status200
-        [("Content-Type", "text/plain")]
-        "test"
+    gzip def $ \_ f ->
+        f . changeRes $
+            responseLBS
+                status200
+                [("Content-Type", "text/plain")]
+                "test"
 
 gzipAppWithHeaders :: ResponseHeaders -> Application
-gzipAppWithHeaders hdrs = gzipApp' $ mapResponseHeaders $ (hdrs ++)
+gzipAppWithHeaders hdrs = gzipApp' $ mapResponseHeaders (hdrs ++)
 
 gzipFileApp :: GzipSettings -> Application
 gzipFileApp = flip gzipFileApp' id
@@ -205,8 +226,9 @@ gzipNocompressBody = "noprecompress\n"
 -- | Use 'changeRes' to make r
 gzipFileApp' :: GzipSettings -> (Response -> Response) -> Application
 gzipFileApp' set changeRes =
-    gzip set $ \_ f -> f . changeRes $
-        responseFile status200 [(hContentType, "application/json")] gzipJSONFile Nothing
+    gzip set $ \_ f ->
+        f . changeRes $
+            responseFile status200 [(hContentType, "application/json")] gzipJSONFile Nothing
 
 acceptGzip :: Header
 acceptGzip = (hAcceptEncoding, "gzip")
@@ -222,9 +244,11 @@ doesEncodeGzipNoPreCompress = doesEncodeGzip' gzipNocompressBody
 
 doesEncodeGzip' :: L.ByteString -> RequestHeaders -> Session SResponse
 doesEncodeGzip' body hdrs = do
-    sres <- request defaultRequest
-        { requestHeaders = hdrs
-        }
+    sres <-
+        request
+            defaultRequest
+                { requestHeaders = hdrs
+                }
     assertHeader hContentEncoding "gzip" sres
     assertHeader hVary "Accept-Encoding" sres
     liftIO $ decompress (simpleBody sres) @?= body
@@ -241,9 +265,11 @@ doesNotEncodeGzipNoPreCompress = doesNotEncodeGzip' gzipNocompressBody
 
 doesNotEncodeGzip' :: L.ByteString -> RequestHeaders -> Session SResponse
 doesNotEncodeGzip' body hdrs = do
-    sres <- request defaultRequest
-        { requestHeaders = hdrs
-        }
+    sres <-
+        request
+            defaultRequest
+                { requestHeaders = hdrs
+                }
     assertNoHeader hContentEncoding sres
     assertHeader hVary "Accept-Encoding" sres
     assertBody body sres
@@ -280,15 +306,19 @@ caseGzipPartial =
 caseGzip2 :: Assertion
 caseGzip2 =
     withSession gzipVariantApp $ do
-        sres1 <- request defaultRequest
-                    { requestHeaders = [(hAcceptEncoding, "compress, gzip")] }
+        sres1 <-
+            request
+                defaultRequest
+                    { requestHeaders = [(hAcceptEncoding, "compress, gzip")]
+                    }
         assertHeader hContentEncoding "compress" sres1
         assertHeader hVary "Accept-Encoding, foobar" sres1
   where
-    gzipVariantApp = gzipAppWithHeaders
-        [ ("Content-Encoding", "compress")
-        , ("Vary", "foobar")
-        ]
+    gzipVariantApp =
+        gzipAppWithHeaders
+            [ ("Content-Encoding", "compress")
+            , ("Vary", "foobar")
+            ]
 
 -- | Testing of the GzipSettings's 'GzipFiles' setting
 -- with 'ResponseFile' responses.
@@ -308,8 +338,11 @@ caseGzipFiles = do
 
     -- Checks for a "filename.gz" file in the same folder
     withSession (gzipFileApp def{gzipFiles = GzipPreCompressed GzipIgnore}) $ do
-        sres <- request defaultRequest
-            { requestHeaders = [acceptGzip] }
+        sres <-
+            request
+                defaultRequest
+                    { requestHeaders = [acceptGzip]
+                    }
         assertHeader hContentEncoding "gzip" sres
         assertHeader hVary "Accept-Encoding" sres
         -- json.gz has body "test\n"
@@ -363,11 +396,16 @@ caseGzipFiles = do
         withSession (gzipFileApp def{gzipFiles = GzipCacheFolder path}) $ do
             _ <- doesEncodeGzipJSON [acceptGzip]
             liftIO $ checkTempDir 2 "just to make sure it isn't a fluke"
-
   where
-    noPreCompressApp set = gzipFileApp'
-        def{gzipFiles = set}
-        $ const $ responseFile status200 [(hContentType, "text/plain")] gzipNoPreCompressFile Nothing
+    noPreCompressApp set =
+        gzipFileApp'
+            def{gzipFiles = set}
+            $ const
+            $ responseFile
+                status200
+                [(hContentType, "text/plain")]
+                gzipNoPreCompressFile
+                Nothing
 
 caseDefaultCheckMime :: Assertion
 caseDefaultCheckMime = do
@@ -381,10 +419,11 @@ caseDefaultCheckMime = do
 
 caseGzipMSIE :: Assertion
 caseGzipMSIE = withSession gzipApp $ do
-    sres1 <- doesNotEncodeGzip
-        [ acceptGzip
-        , ("User-Agent", "Mozilla/4.0 (Windows; MSIE 6.0; Windows NT 6.0)")
-        ]
+    sres1 <-
+        doesNotEncodeGzip
+            [ acceptGzip
+            , ("User-Agent", "Mozilla/4.0 (Windows; MSIE 6.0; Windows NT 6.0)")
+            ]
     assertHeader "Vary" "Accept-Encoding" sres1
 
 caseGzipBypassPre :: Assertion
@@ -393,7 +432,7 @@ caseGzipBypassPre =
     -- that the compression is skipped based on the presence of
     -- the Content-Encoding header.
     withSession (gzipAppWithHeaders [(hContentEncoding, "gzip")]) $ do
-        sres1 <- request defaultRequest{ requestHeaders = [acceptGzip] }
+        sres1 <- request defaultRequest{requestHeaders = [acceptGzip]}
         assertHeader "Content-Encoding" "gzip" sres1
         assertHeader "Vary" "Accept-Encoding" sres1
         assertBody "test" sres1 -- the body is not actually compressed
@@ -401,60 +440,83 @@ caseGzipBypassPre =
 vhostApp1, vhostApp2, vhostApp :: Application
 vhostApp1 _ f = f $ responseLBS status200 [] "app1"
 vhostApp2 _ f = f $ responseLBS status200 [] "app2"
-vhostApp = vhost
-    [ ((== Just "foo.com") . lookup "host" . requestHeaders, vhostApp1)
-    ]
-    vhostApp2
+vhostApp =
+    vhost
+        [ ((== Just "foo.com") . lookup "host" . requestHeaders, vhostApp1)
+        ]
+        vhostApp2
 
 caseVhost :: Assertion
 caseVhost = withSession vhostApp $ do
-    sres1 <- request defaultRequest
+    sres1 <-
+        request
+            defaultRequest
                 { requestHeaders = [("Host", "foo.com")]
                 }
     assertBody "app1" sres1
 
-    sres2 <- request defaultRequest
+    sres2 <-
+        request
+            defaultRequest
                 { requestHeaders = [("Host", "bar.com")]
                 }
     assertBody "app2" sres2
 
 autoheadApp :: Application
-autoheadApp = autohead $ \_ f -> f $ responseLBS status200
-    [("Foo", "Bar")] "body"
+autoheadApp = autohead $ \_ f ->
+    f $
+        responseLBS
+            status200
+            [("Foo", "Bar")]
+            "body"
 
 caseAutohead :: Assertion
 caseAutohead = withSession autoheadApp $ do
-    sres1 <- request defaultRequest
+    sres1 <-
+        request
+            defaultRequest
                 { requestMethod = "GET"
                 }
     assertHeader "Foo" "Bar" sres1
     assertBody "body" sres1
 
-    sres2 <- request defaultRequest
+    sres2 <-
+        request
+            defaultRequest
                 { requestMethod = "HEAD"
                 }
     assertHeader "Foo" "Bar" sres2
     assertBody "" sres2
 
 moApp :: Application
-moApp = methodOverride $ \req f -> f $ responseLBS status200
-    [("Method", requestMethod req)] ""
+moApp = methodOverride $ \req f ->
+    f $
+        responseLBS
+            status200
+            [("Method", requestMethod req)]
+            ""
 
 caseMethodOverride :: Assertion
 caseMethodOverride = withSession moApp $ do
-    sres1 <- request defaultRequest
+    sres1 <-
+        request
+            defaultRequest
                 { requestMethod = "GET"
                 , queryString = []
                 }
     assertHeader "Method" "GET" sres1
 
-    sres2 <- request defaultRequest
+    sres2 <-
+        request
+            defaultRequest
                 { requestMethod = "POST"
                 , queryString = []
                 }
     assertHeader "Method" "POST" sres2
 
-    sres3 <- request defaultRequest
+    sres3 <-
+        request
+            defaultRequest
                 { requestMethod = "POST"
                 , queryString = [("_method", Just "PUT")]
                 }
@@ -465,46 +527,61 @@ mopApp = methodOverridePost $ \req f -> f $ responseLBS status200 [("Method", re
 
 caseMethodOverridePost :: Assertion
 caseMethodOverridePost = withSession mopApp $ do
-
     -- Get Request are unmodified
-    sres1 <- let r = toRequest "application/x-www-form-urlencoded" "_method=PUT&foo=bar&baz=bin"
-                 s = simpleRequest r
-                 m = s { requestMethod = "GET" }
-                 b = r { simpleRequest = m }
-             in srequest b
+    sres1 <-
+        let r = toRequest "application/x-www-form-urlencoded" "_method=PUT&foo=bar&baz=bin"
+            s = simpleRequest r
+            m = s{requestMethod = "GET"}
+            b = r{simpleRequest = m}
+         in srequest b
     assertHeader "Method" "GET" sres1
 
     -- Post requests are modified if _method comes first
-    sres2 <- srequest $ toRequest "application/x-www-form-urlencoded" "_method=PUT&foo=bar&baz=bin"
+    sres2 <-
+        srequest $
+            toRequest "application/x-www-form-urlencoded" "_method=PUT&foo=bar&baz=bin"
     assertHeader "Method" "PUT" sres2
 
     -- Post requests are unmodified if _method doesn't come first
-    sres3 <- srequest $ toRequest "application/x-www-form-urlencoded" "foo=bar&_method=PUT&baz=bin"
+    sres3 <-
+        srequest $
+            toRequest "application/x-www-form-urlencoded" "foo=bar&_method=PUT&baz=bin"
     assertHeader "Method" "POST" sres3
 
     -- Post requests are unmodified if Content-Type header isn't set to "application/x-www-form-urlencoded"
-    sres4 <- srequest $ toRequest "text/html; charset=utf-8" "foo=bar&_method=PUT&baz=bin"
+    sres4 <-
+        srequest $ toRequest "text/html; charset=utf-8" "foo=bar&_method=PUT&baz=bin"
     assertHeader "Method" "POST" sres4
 
 aoApp :: Application
-aoApp = acceptOverride $ \req f -> f $ responseLBS status200
-    [("Accept", fromMaybe "" $ lookup "Accept" $ requestHeaders req)] ""
+aoApp = acceptOverride $ \req f ->
+    f $
+        responseLBS
+            status200
+            [("Accept", fromMaybe "" $ lookup "Accept" $ requestHeaders req)]
+            ""
 
 caseAcceptOverride :: Assertion
 caseAcceptOverride = withSession aoApp $ do
-    sres1 <- request defaultRequest
+    sres1 <-
+        request
+            defaultRequest
                 { queryString = []
                 , requestHeaders = [("Accept", "foo")]
                 }
     assertHeader "Accept" "foo" sres1
 
-    sres2 <- request defaultRequest
+    sres2 <-
+        request
+            defaultRequest
                 { queryString = []
                 , requestHeaders = [("Accept", "bar")]
                 }
     assertHeader "Accept" "bar" sres2
 
-    sres3 <- request defaultRequest
+    sres3 <-
+        request
+            defaultRequest
                 { queryString = [("_accept", Just "baz")]
                 , requestHeaders = [("Accept", "bar")]
                 }
@@ -519,26 +596,35 @@ caseDebugRequestBody = do
 
     let qs = "?foo=bar&baz=bin"
     withSession (debugApp $ getOutput params) $ do
-        assertStatus 200 =<< request defaultRequest
-                { requestMethod = "GET"
-                , queryString = map (\(k,v) -> (k, Just v)) params
-                , rawQueryString = qs
-                , requestHeaders = []
-                , rawPathInfo = "/location"
-                }
+        assertStatus 200
+            =<< request
+                defaultRequest
+                    { requestMethod = "GET"
+                    , queryString = map (\(k, v) -> (k, Just v)) params
+                    , rawQueryString = qs
+                    , requestHeaders = []
+                    , rawPathInfo = "/location"
+                    }
   where
     params = [("foo", "bar"), ("baz", "bin")]
     -- the time cannot be known, so match around it
-    postOutput = (T.pack $ "POST /\n  Params: " ++ (show params), "s\n")
-    getOutput params' = ("GET /location\n  Params: " <> T.pack (show params') <> "\n  Accept: \n  Status: 200 OK 0", "s\n")
+    postOutput = (T.pack $ "POST /\n  Params: " ++ show params, "s\n")
+    getOutput params' =
+        ( "GET /location\n  Params: "
+            <> T.pack (show params')
+            <> "\n  Accept: \n  Status: 200 OK 0"
+        , "s\n"
+        )
 
     debugApp (beginning, ending) req send = do
         iactual <- I.newIORef mempty
-        middleware <- mkRequestLogger def
-            { destination = Callback $ \strs -> I.modifyIORef iactual $ (`mappend` strs)
-            , outputFormat = Detailed False
-            }
-        res <- middleware (\_req f -> f $ responseLBS status200 [ ] "") req send
+        middleware <-
+            mkRequestLogger
+                def
+                    { destination = Callback $ \strs -> I.modifyIORef iactual (`mappend` strs)
+                    , outputFormat = Detailed False
+                    }
+        res <- middleware (\_req f -> f $ responseLBS status200 [] "") req send
         actual <- logToBs <$> I.readIORef iactual
         actual `shouldSatisfy` S.isPrefixOf begin
         actual `shouldSatisfy` S.isSuffixOf end
@@ -546,72 +632,73 @@ caseDebugRequestBody = do
         return res
       where
         begin = TE.encodeUtf8 $ T.toStrict beginning
-        end   = TE.encodeUtf8 $ T.toStrict ending
+        end = TE.encodeUtf8 $ T.toStrict ending
 
         logToBs = fromLogStr
 
-    {-debugApp = debug $ \req -> do-}
-        {-return $ responseLBS status200 [ ] ""-}
+{-debugApp = debug $ \req -> do-}
+{-return $ responseLBS status200 [ ] ""-}
 
 urlMapTestApp :: Application
-urlMapTestApp = mapUrls $
-        mount "bugs"     bugsApp
-    <|> mount "helpdesk" helpdeskApp
-    <|> mount "api"
-            (   mount "v1" apiV1
-            <|> mount "v2" apiV2
-            )
-    <|> mountRoot mainApp
-
+urlMapTestApp =
+    mapUrls $
+        mount "bugs" bugsApp
+            <|> mount "helpdesk" helpdeskApp
+            <|> mount
+                "api"
+                ( mount "v1" apiV1
+                    <|> mount "v2" apiV2
+                )
+            <|> mountRoot mainApp
   where
-  trivialApp :: S.ByteString -> Application
-  trivialApp name req f =
-    f $
-      responseLBS
-        status200
-        [ ("content-type", "text/plain")
-        , ("X-pathInfo",    S8.pack . show . pathInfo $ req)
-        , ("X-rawPathInfo", rawPathInfo req)
-        , ("X-appName",     name)
-        ]
-        ""
+    trivialApp :: S.ByteString -> Application
+    trivialApp name req f =
+        f $
+            responseLBS
+                status200
+                [ ("content-type", "text/plain")
+                , ("X-pathInfo", S8.pack . show . pathInfo $ req)
+                , ("X-rawPathInfo", rawPathInfo req)
+                , ("X-appName", name)
+                ]
+                ""
 
-  bugsApp     = trivialApp "bugs"
-  helpdeskApp = trivialApp "helpdesk"
-  apiV1       = trivialApp "apiv1"
-  apiV2       = trivialApp "apiv2"
-  mainApp     = trivialApp "main"
+    bugsApp = trivialApp "bugs"
+    helpdeskApp = trivialApp "helpdesk"
+    apiV1 = trivialApp "apiv1"
+    apiV2 = trivialApp "apiv2"
+    mainApp = trivialApp "main"
 
 casesUrlMap :: [(String, Assertion)]
 casesUrlMap = [pair1, pair2, pair3, pair4]
   where
-  makePair name session = (name, runSession session urlMapTestApp)
-  get reqPath = request $ setPath defaultRequest reqPath
-  s = S8.pack . show :: [TS.Text] -> S.ByteString
+    makePair name session = (name, runSession session urlMapTestApp)
+    get reqPath = request $ setPath defaultRequest reqPath
+    s = S8.pack . show :: [TS.Text] -> S.ByteString
 
-  pair1 = makePair "should mount root" $ do
-    res1 <- get "/"
-    assertStatus 200 res1
-    assertHeader "X-rawPathInfo" "/"    res1
-    assertHeader "X-pathInfo"    (s []) res1
-    assertHeader "X-appName"     "main" res1
+    pair1 = makePair "should mount root" $ do
+        res1 <- get "/"
+        assertStatus 200 res1
+        assertHeader "X-rawPathInfo" "/" res1
+        assertHeader "X-pathInfo" (s []) res1
+        assertHeader "X-appName" "main" res1
 
-  pair2 = makePair "should mount apps" $ do
-    res2 <- get "/bugs"
-    assertStatus 200 res2
-    assertHeader "X-rawPathInfo" "/"    res2
-    assertHeader "X-pathInfo"    (s []) res2
-    assertHeader "X-appName"     "bugs" res2
+    pair2 = makePair "should mount apps" $ do
+        res2 <- get "/bugs"
+        assertStatus 200 res2
+        assertHeader "X-rawPathInfo" "/" res2
+        assertHeader "X-pathInfo" (s []) res2
+        assertHeader "X-appName" "bugs" res2
 
-  pair3 = makePair "should preserve extra path info" $ do
-    res3 <- get "/helpdesk/issues/11"
-    assertStatus 200 res3
-    assertHeader "X-rawPathInfo" "/issues/11"         res3
-    assertHeader "X-pathInfo"    (s ["issues", "11"]) res3
+    pair3 = makePair "should preserve extra path info" $ do
+        res3 <- get "/helpdesk/issues/11"
+        assertStatus 200 res3
+        assertHeader "X-rawPathInfo" "/issues/11" res3
+        assertHeader "X-pathInfo" (s ["issues", "11"]) res3
 
-  pair4 = makePair "should 404 if none match" $ do
-    res4 <- get "/api/v3"
-    assertStatus 404 res4
+    pair4 = makePair "should 404 if none match" $ do
+        res4 <- get "/api/v3"
+        assertStatus 404 res4
 
 testFile :: FilePath
 testFile = "test/WaiExtraSpec.hs"
@@ -627,9 +714,12 @@ caseStreamFile = withSession streamFileApp $ do
     assertNoHeader "Transfer-Encoding" sres
 
 streamLBSApp :: Application
-streamLBSApp = streamFile $ \_ f -> f $ responseLBS status200
-    [("Content-Type", "text/plain")]
-    "test"
+streamLBSApp = streamFile $ \_ f ->
+    f $
+        responseLBS
+            status200
+            [("Content-Type", "text/plain")]
+            "test"
 
 caseStreamLBS :: Assertion
 caseStreamLBS = withSession streamLBSApp $ do
@@ -641,8 +731,9 @@ caseModifyPostParamsInLogs :: Assertion
 caseModifyPostParamsInLogs = do
     let formatUnredacted = DetailedWithSettings $ DetailedSettings False Nothing Nothing False
         outputUnredacted = [("username", "some_user"), ("password", "dont_show_me")]
-        formatRedacted = DetailedWithSettings $ DetailedSettings False (Just hidePasswords) Nothing False
-        hidePasswords p@(k,_) = Just $ if k == "password" then (k, "***REDACTED***") else p
+        formatRedacted =
+            DetailedWithSettings $ DetailedSettings False (Just hidePasswords) Nothing False
+        hidePasswords p@(k, _) = Just $ if k == "password" then (k, "***REDACTED***") else p
         outputRedacted = [("username", "some_user"), ("password", "***REDACTED***")]
 
     testLogs formatUnredacted outputUnredacted
@@ -650,21 +741,25 @@ caseModifyPostParamsInLogs = do
   where
     testLogs :: OutputFormat -> [(String, String)] -> Assertion
     testLogs format output = withSession (debugApp format output) $ do
-        let req = toRequest "application/x-www-form-urlencoded" "username=some_user&password=dont_show_me"
+        let req =
+                toRequest
+                    "application/x-www-form-urlencoded"
+                    "username=some_user&password=dont_show_me"
         res <- srequest req
         assertStatus 200 res
 
     postOutputStart params = TE.encodeUtf8 $ T.toStrict $ "POST /\n  Params: " <> (T.pack . show $ params)
     postOutputEnd = TE.encodeUtf8 $ T.toStrict "s\n"
 
-
     debugApp format output req send = do
         iactual <- I.newIORef mempty
-        middleware <- mkRequestLogger def
-            { destination = Callback $ \strs -> I.modifyIORef iactual (`mappend` strs)
-            , outputFormat = format
-            }
-        res <- middleware (\_req f -> f $ responseLBS status200 [ ] "") req send
+        middleware <-
+            mkRequestLogger
+                def
+                    { destination = Callback $ \strs -> I.modifyIORef iactual (`mappend` strs)
+                    , outputFormat = format
+                    }
+        res <- middleware (\_req f -> f $ responseLBS status200 [] "") req send
         actual <- fromLogStr <$> I.readIORef iactual
         actual `shouldSatisfy` S.isPrefixOf (postOutputStart output)
         actual `shouldSatisfy` S.isSuffixOf postOutputEnd
@@ -674,7 +769,9 @@ caseModifyPostParamsInLogs = do
 caseFilterRequestsInLogs :: Assertion
 caseFilterRequestsInLogs = do
     let formatUnfiltered = DetailedWithSettings $ DetailedSettings False Nothing Nothing False
-        formatFiltered = DetailedWithSettings $ DetailedSettings False Nothing (Just hideHealthCheck) False
+        formatFiltered =
+            DetailedWithSettings $
+                DetailedSettings False Nothing (Just hideHealthCheck) False
         pathHidden = "/health-check"
         pathNotHidden = "/foobar"
 
@@ -696,33 +793,35 @@ caseFilterRequestsInLogs = do
 
     debugApp format rpath haslogs req send = do
         iactual <- I.newIORef mempty
-        middleware <- mkRequestLogger def
-            { destination = Callback $ \strs -> I.modifyIORef iactual (`mappend` strs)
-            , outputFormat = format
-            }
-        res <- middleware (\_req f -> f $ responseLBS status200 [ ] "") req send
+        middleware <-
+            mkRequestLogger
+                def
+                    { destination = Callback $ \strs -> I.modifyIORef iactual (`mappend` strs)
+                    , outputFormat = format
+                    }
+        res <- middleware (\_req f -> f $ responseLBS status200 [] "") req send
         actual <- fromLogStr <$> I.readIORef iactual
         if haslogs
-          then do
-            actual `shouldSatisfy` S.isPrefixOf ("GET " <> rpath <> "\n")
-            actual `shouldSatisfy` S.isSuffixOf "s\n"
-          else
-            actual `shouldBe` ""
+            then do
+                actual `shouldSatisfy` S.isPrefixOf ("GET " <> rpath <> "\n")
+                actual `shouldSatisfy` S.isSuffixOf "s\n"
+            else actual `shouldBe` ""
 
         return res
 
 -- | Unit test to make sure 'parseQValueList' works correctly
 caseQValues :: Assertion
 caseQValues = do
-    let encodings = mconcat
-            -- This has weird white space on purpose, because this
-            -- should be acceptable according to RFC 7231
-            [ "deflate,   compress; q=0.813  ,gzip ;  q=0.9, * ;q=0, "
-            , "notq;charset=bar, "
-            , "noq;q=,   "
-            , "toolong;q=0.0023, "
-            , "toohigh ;q=1.1"
-            ]
+    let encodings =
+            mconcat
+                -- This has weird white space on purpose, because this
+                -- should be acceptable according to RFC 7231
+                [ "deflate,   compress; q=0.813  ,gzip ;  q=0.9, * ;q=0, "
+                , "notq;charset=bar, "
+                , "noq;q=,   "
+                , "toolong;q=0.0023, "
+                , "toohigh ;q=1.1"
+                ]
         qList = parseQValueList encodings
         expected =
             [ ("deflate", Just 1000)
